pyxmpp2.binding

Package pyxmpp2 :: Module binding |
[hide private]

# Module binding

Resource binding implementation.

Normative reference:
  - RFC 6120

Classes | [hide private]
| ResourceBindingPayload Resource binding <iq/> stanza payload.
| ResourceBindingHandler Resource binding implementation.

Functions | [hide private]
default_resource_factory(settings) Factory for the 'resource' setting default: use random uuid |

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.binding")`
| FEATURE_BIND = ``u'``{urn:ietf:params:xml:ns:xmpp-bind}bind``'``
| BIND_JID_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-bind}jid``'``
| BIND_RESOURCE_TAG = ``u'``{urn:ietf:params:xml:ns:xmpp-bind}resource``'``